The function is called from the main print function print.CAvariants.
It adds the names to objects.
printwithaxes(x, thenames,digits=3)An R object.
A character vector of up to the same length as x.
The minimum number of significant digits to be printed in values. By default, digits = 3.
Beh EJ and Lombardo R 2014 Correspondence Analysis: Theory, Practice and New Strategies. John Wiley & Sons. Lombardo R Beh EJ 2016 Variants of Simple Correspondence Analysis. The R Journal, 8 (2), 167--184.